@@ -1,8 +1,18 @@
-
+#' Print scppp objects
+#'
+#' @param x An object of class `scppp`.
+#' @param ... Further arguments passed to or from other methods
+#' @export
 print.scppp <- function(x, ...) {
   cat("An object of class scppp\n")
-  cat("  * data = [",paste0(dim(x$data), collapse = " x ") ,
-      "] <",paste0(class(x$data),collapse = "/"),"> ", sep = "")
+  cat(
+    "  * data = [",
+    paste0(dim(x$data), collapse = " x "),
+    "] <",
+    paste0(class(x$data), collapse = "/"),
+    "> ",
+    sep = ""
+  )
 }
 
 #' get example data
