@@ -290,8 +290,8 @@ qqplot_env_pois.numeric <- function(sample_data, lambda, envelope_size = 100, ..
   #size <- 18
   p <- ggplot(data = df_all) +
     geom_line(aes(x = .data$value_new_q, y=.data$value_new_p, group = .data$sim),
-              color = "gray", size = 1.2) +
-    geom_line(data = test_all_qq, aes(x = .data$value_new_q, y = .data$value_new_p, color = source), size = 1.2) +
+              color = "gray", linewidth = 1.2) +
+    geom_line(data = test_all_qq, aes(x = .data$value_new_q, y = .data$value_new_p, color = source), linewidth = 1.2) +
     geom_point(data = test_all_qq, aes(x = .data$value_new_q, y = .data$value_new_p, color = source), size = 1.5) +
     scale_color_manual(values=c("#E69F00")) +
     geom_abline(intercept = 0, slope = 1, color = "black", linetype = "dashed") +
@@ -303,16 +303,17 @@ qqplot_env_pois.numeric <- function(sample_data, lambda, envelope_size = 100, ..
 }
 
 #' @param L A numeric value specifying the number of latent vectors included when estimate the Poisson parameter for each matrix entry. This is not useful if a numeric vector is used as input.
-#' @param select_by A character indicating whether entries should be selected by
-#' \itemize{
-#' \item{entry}: {independent matrix entries with Poisson parameter estimates closest to \code{lambda}}
-#' \item{\code{cell}}: {one particular cell with UMI count mean closest to \code{lambda}}
-#' \item{\code{gene}}: {one particular gene with UMI count mean closest to \code{lambda}}
+#' @param select_by A character indicating whether entries should be selected:
+#' \describe{
+#'   \item{entry}{Independent matrix entries with Poisson parameter estimates closest to \code{lambda}}
+#'   \item{cell}{One particular cell with UMI count mean closest to \code{lambda}}
+#'   \item{gene}{One particular gene with UMI count mean closest to \code{lambda}}
 #' }
 #' This is not useful if a numeric vector is used as input.
 #' @param entry_size A numeric value specifying the number of entries used to compare with the theoretical Poisson distribution.
 #' This is not useful if a numeric vector is used as input, or the entries are selected by cell or gene.
-#' @export
+#' @rdname qqplot_env_pois
+#' @exportS3Method qqplot_env_pois scppp
 qqplot_env_pois.scppp <- function(sample_data, lambda, envelope_size = 100,
                                   L = 10,
                                   select_by = "entry",
